@@ -37,7 +37,7 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
-$Id: combroyden2.c 2067 2012-07-27 20:59:32Z beerli $
+$Id: combroyden2.c 2120 2013-01-03 05:17:21Z beerli $
  
 -------------------------------------------------------*/
 
@@ -320,6 +320,9 @@ calc_loci_like (helper_fmt * helper, MYREAL *param, MYREAL *lparam)
     nr_fmt *nr = helper->nr;
     world_fmt *world = helper->nr->world;
     MYREAL logres = 0;
+
+    MYREAL * locusweight = nr->world->data->locusweight;
+
     if (helper->multilocus)
     {
 #ifdef MPI
@@ -338,7 +341,7 @@ calc_loci_like (helper_fmt * helper, MYREAL *param, MYREAL *lparam)
                     continue;
                 nr->locilikes[locus] =
 		  calc_locus_like (nr, param, lparam, locus) + mu_rates[locus];
-                logres += nr->locilikes[locus];
+                logres += locusweight[locus] * nr->locilikes[locus]; //invariant loci treatment
             }
         }
         else
@@ -364,6 +367,7 @@ slow_net_calc_loci_like (helper_fmt * helper, MYREAL *param, MYREAL *lparam)
     world_fmt *world = helper->nr->world;
     MYREAL *mu_rates = world->options->mu_rates;
     MYREAL logres = 0;
+    MYREAL *locusweight = helper->nr->world->data->locusweight; //invariant loci treatment
     if (helper->multilocus)
     {
         if (!helper->boolgamma)
@@ -374,7 +378,7 @@ slow_net_calc_loci_like (helper_fmt * helper, MYREAL *param, MYREAL *lparam)
                     continue;
                 nr->locilikes[locus] =
 		  calc_locus_like (nr, param, lparam, locus) + mu_rates[locus];
-                logres += nr->locilikes[locus];
+                logres += locusweight[locus] * nr->locilikes[locus];
             }
         }
         else
@@ -605,10 +609,10 @@ print_menu_finalestimate (boolean progress, long locus, long loci)
     {
         get_time (nowstr, "%H:%M:%S");
         if (locus < loci)
-            FPRINTF (stdout, "%s   Parameter estimation for locus %li\n", nowstr,
+            fprintf (stdout, "%s   Parameter estimation for locus %li\n", nowstr,
                      locus);
         else
-            FPRINTF (stdout, "%s   Parameter estimation over all loci\n", nowstr);
+            fprintf (stdout, "%s   Parameter estimation over all loci\n", nowstr);
     }
 }
 
@@ -1556,7 +1560,7 @@ finish_broyden (MYREAL newL, MYREAL normd, long trials,
         tyme[0][loci].trials = trials;
         memmove (tyme[0][loci].param, expxv, sizeof (MYREAL) * nn);
         nr->normd = normd;
-        convergence_check (world, world->options->verbose);
+        //convergence_check (world, world->options->verbose);
         break;
     case SINGLELOCUS:
         world->param_like = newL;
