@@ -153,7 +153,7 @@ void covariance_summary(world_fmt *world)
 {
   const long nn = world->numpop2;
   bayeshistogram_fmt *target = &world->bayes->histogram[world->loci];
-  const MYREAL invn = 1.0 / world->loci;
+  const MYREAL invn = 1.0 / (world->loci);
   long i,j,locus;
   MYREAL **cov;
   if(world->bayes->histogram[0].covariance==NULL)
@@ -164,12 +164,15 @@ void covariance_summary(world_fmt *world)
     }
   for (locus=0;locus<world->loci;locus++)
     {
-      cov = world->bayes->histogram[locus].covariance;
-      for(i=0;i<nn;i++)
+      if (!world->data->skiploci[locus])
 	{
-	  for(j=0;j<nn;j++)
+	  cov = world->bayes->histogram[locus].covariance;
+	  for(i=0;i<nn;i++)
 	    {
-	      target->covariance[i][j] += cov[i][j]*invn;
+	      for(j=0;j<nn;j++)
+		{
+		  target->covariance[i][j] += cov[i][j]*invn;
+		}
 	    }
 	}
     }
