@@ -31,7 +31,7 @@ HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTIO
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
-$Id: data.c 2127 2013-01-30 10:13:45Z beerli $
+$Id: data.c 2160 2013-06-06 21:20:59Z beerli $
 
 -----------------------------------
 add this to the microsatellite data, this will allow to use
@@ -52,7 +52,10 @@ Data manipulation routines
 
 
 #include <string.h>
-
+#include <wchar.h>
+#ifndef WIN32
+#include <xlocale.h>
+#endif
 #include "migration.h"
 #include "sighandler.h"
 #include "tools.h"
@@ -614,6 +617,9 @@ init_data_structure2 (data_fmt ** data, option_fmt * options, long pop)
                 (*data)->yy[pop][ind][locus][0] =
                     (char *) mycalloc (1,
                                      sizeof (char) * ((*data)->seq[0]->sites[locus]+1));
+#ifdef DEBUG
+		printf("%i> sites=%li+1, pop=%li ind=%li locus=%li\n",myID, ((*data)->seq[0]->sites[locus]+1),pop, ind, locus);
+#endif
             }
         }
     }
@@ -685,6 +691,40 @@ init_data_structure3 (data_fmt * data, option_fmt *options)
       }
 }
 
+void print_utf_warning(void)
+{
+  warning("Tried and failed to read a file that is not in ASCII TEXT format\n");
+  warning("This is most commonly UTF-8 or UTF-16 formatted\n");
+  warning("Try to convert the file into plain ASCII, enclodings like\n");
+  warning("WESTERN (MAC ROMAN) or WESTERN (WINDOWS LATIN 1) or WESTERN ISO LATIN\n");
+  usererror("Program aborts now\n");
+}
+
+void check_ascii(FILE *infile)
+{
+  wint_t wch, wch2;
+  wch = fgetwc(infile);
+  if (wch > 127)
+    {
+      print_utf_warning();
+    }
+  else
+    {
+      wch2 = fgetwc(infile);
+      if(wch==0 && wch2>0)
+	{
+	  print_utf_warning();
+	}
+      else
+	{
+	  if (wch>0 && wch2==0)
+	    {
+	      print_utf_warning();
+	    }
+	}
+      rewind(infile);
+    }
+}
 ///
 /// read the first line of the data file
 /// \param infile datafilename
@@ -696,10 +736,14 @@ void read_header (FILE * infile, data_fmt * data, option_fmt * options)
     char input[LINESIZE], *p;
     char title[LINESIZE];
     strcpy(title,"\0");
+    //disabled for now: check_ascii(infile);
     input[0] = '#';
     while(input[0]=='#')
       {
 	FGETS (input, sizeof (input), infile);
+#ifdef DEBUG
+	printf("@@>%s<@@\n",input);
+#endif      
 	if ((p = (char *) strpbrk (input, CRLF)) != NULL)
 	  *p = '\0';
       }
