@@ -11,14 +11,27 @@ using a Metropolis-Hastings Monte Carlo algorithm
  beerli@fsu.edu
  
  Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
-Copyright 2003-2004 Peter Beerli, Tallahassee FL
+ Copyright 2003-2004 Peter Beerli, Tallahassee FL
  
- This software is distributed free of charge for non-commercial use
- and is copyrighted. Of course, we do not guarantee that the software
- works and are not responsible for any damage you may cause or have.
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
+of the Software, and to permit persons to whom the Software is furnished to do
+so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all copies
+or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
+PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
+OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
  
- 
-$Id: fst.c 1807 2011-03-18 20:16:19Z beerli $
+$Id: fst.c 2139 2013-03-03 22:13:06Z beerli $
  
 -------------------------------------------------------*/
 /*! \file fst.c
@@ -90,7 +103,7 @@ calc_fst (world_fmt * world, data_fmt * data)
     fstfreq = (MYREAL ***) mycalloc (world->numpop, sizeof (MYREAL **));
     for (pop = 0; pop < world->numpop; pop++)
     {
-        doublevec2d(&fstfreq[pop],world->loci,255);  
+        doublevec2d(&fstfreq[pop],world->loci,255L);  
         //fstfreq[pop] =
         //     (MYREAL **) mycalloc (world->loci, sizeof (MYREAL *));
         //for (locus = 0; locus < world->loci; locus++)
@@ -139,7 +152,7 @@ calc_fst (world_fmt * world, data_fmt * data)
       (*solveNm) (sumfw, sumfb, world->numpop, world->fstparam[world->loci]);
     if (!strchr (SEQUENCETYPES, world->options->datatype))
     {
-      for (pop = world->numpop; pop >= 0; pop++)
+      for (pop = world->numpop-1; pop >= 0; pop--)
         {
           free_doublevec2d(fstfreq[pop]);
 //          for (locus = world->loci-1; locus >= 0; locus--)
