@@ -155,13 +155,13 @@ pdf_cid_type2_fontdef_cid_width(pdf_cid_type2_fontdef font, unsigned int cid)
 const char* 
 pdf_cid_type2_fontdef_basefont(pdf_cid_type2_fontdef font)
 {
-    return (font != NULL) ? ((PdfCIDType2FontDef*)font)->BaseFont() : NULL;
+    return (font != NULL) ? ((PdfCIDType2FontDef*)font)->BaseFont() : 0;
 }
 
 int 
 pdf_cid_type2_fontdef_ascent(pdf_cid_type2_fontdef font)
 {
-    return (font != NULL) ? ((PdfCIDType2FontDef*)font)->Ascent() : NULL;
+    return (font != NULL) ? ((PdfCIDType2FontDef*)font)->Ascent() : 0;
 }
 
 int 
@@ -380,6 +380,23 @@ pdf_pages_get_rotate(pdf_pages pages)
     return ((PdfPageBase*)pages)->Rotate();
 }
 
+
+// BEERLI addition for missing set_rotate interface
+
+void
+pdf_pages_set_rotate(pdf_pages pages, int degree)
+{
+    if (pages != NULL)
+      ((PdfPageBase*)pages)->SetRotate(degree);
+}
+
+void
+pdf_page_set_rotate(pdf_page page, int degree)
+{
+  pdf_pages_set_rotate(page, degree);
+}
+
+
 pdf_pages pdf_pages_get_parent(pdf_pages pages)
 {
     return (pages != NULL) ? ((PdfPageBase*)pages)->Parent() : NULL;
