@@ -167,8 +167,8 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
   long j0, j, z0, z;
   long step;
   long locus;
-  long frompop;
-  long topop;
+  //  long frompop;
+  //long topop;
   long nnn=0;
   long t;
   long bin;
@@ -193,7 +193,7 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
   boolean *done;
   boolean recordedusem = options->usem;
   MYREAL *oldmeans;
-  MYREAL theta;
+  //MYREAL theta;
   boolean notusem = !world->options->usem;
 #ifndef ZNZ
   FILE *mdimfile = fmdimfile;
